Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Loader ¶
type Loader struct {
// contains filtered or unexported fields
}
Loader is used to download different assets in parallel while avoiding downloading artifacts twice.
type LoaderOption ¶
type LoaderOption func(*Loader)
func WithRootPath ¶
func WithRootPath(path string) LoaderOption
WithRootPath defines a custom root path where the loader will output downloaded data.
Click to show internal directories.
Click to hide internal directories.